#!/usr/bin/perl

package App::pmcheck;

=encoding utf8

=head1 NAME

App::pmcheck - show all Perl packages provided or required 

=head1 DESCRIPTION

Dummy package for the CPAN indexer.  See the "pmcheck" script.

=cut

use strict;
use utf8;
use warnings;

use version; our $VERSION = version->new('v1.1.10');

1;
